@@ -1,5 +1,5 @@
-version = '20.4'
-#version += 'a0'
+version = '20.10'
+#version += 'a1'
 
 base_setup = {
     'package_dir': {'': '.'},
@@ -28,17 +28,19 @@ base_setup = {
     },
 }
 
-django_setup = {
-    'classifiers': [
+django_classifiers = [
         'Framework :: Django',
-        'Framework :: Django :: 2.0',
-    ],
-}
+        'Framework :: Django :: 3.0',
+    ]
+
+django_setup = base_setup.copy()
+django_setup['classifiers'] = django_setup['classifiers'].copy()
+django_setup['classifiers'].extend(django_classifiers)
 
 wsgi_extras_require={
         'bjoern': ['bjoern<4'],
         'cheroot': ['cheroot<9'],
         'cherrypy': ['cherrypy<19'],
-        'gunicorn': ['gunicorn<20'],
-        'waitress': ['waitress<1.4'],
+        'gunicorn': ['gunicorn~=20.0'],
+        'waitress': ['waitress~=1.4'],
         }
